/* 
 * GTKSEISVIEWGL - Library for rendering of 2D seismic data
 *
 * Copyright (C) 2006 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEIS_VIEW_DATA_VISIBILITY_H__
#define __G_SEIS_VIEW_DATA_VISIBILITY_H__

#include <GL/gl.h>

G_BEGIN_DECLS

typedef struct {
    guint16  slow_start_screen; /* Start positions (left upper corner and sizes in the */
    guint16  slow_size_screen;  /* screen coordinate system (pixels) of the visible part */
    guint16  fast_start_screen; /* of data */
    guint16  fast_size_screen;
    guint16  slow_pointer_pos_screen; /* Positions of the mouse pointer in the screen space */
    guint16  fast_pointer_pos_screen;

    gdouble  slow_start_object; /* Start positions and sizes in the object coordinate*/
    gdouble  slow_size_object;  /* system ([0; 2], [0; 2]) of the visible part of data*/
    gdouble  fast_start_object;
    gdouble  fast_size_object;
    gdouble  slow_full_size_object; /* Full sizes of the visible area in the object space */
    gdouble  fast_full_size_object; /* (including) borders - needed for axes */
    gdouble  slow_pointer_pos_object; /* Positions of the mouse pointer in the object space */
    gdouble  fast_pointer_pos_object;

    gdouble  slow_start_data; /* Start positions and sizes in the data coordinate system - */
    gdouble  slow_size_data;  /* [0; 1], [0; 1] - of the visible part of data*/
    gdouble  fast_start_data;
    gdouble  fast_size_data;
    gdouble  slow_pointer_pos_data; /* Positions of the mouse pointer in the data space */
    gdouble  fast_pointer_pos_data;
    gdouble  slow_samples_dist_data; /* Distance between samples in the slow dimension */
    gdouble  fast_samples_dist_data; /* Distance between samples in the fast dimension */

    GLint viewport[4]; /* OpenGL viewport matrix */
    GLdouble projection[16]; /* OpenGL projection matrix */
    GLdouble model_view[16]; /* OpenGL model-view matrix */
} GSeisViewDataVisibility;

G_END_DECLS

#endif /* __G_SEIS_VIEW_DATA_VISIBILITY_H__ */
